@@ -17,7 +17,7 @@ use warnings;
 
 {
     package Doit;
-    our $VERSION = '0.025_57';
+    our $VERSION = '0.025_58';
     $VERSION =~ s{_}{};
 
     use constant IS_WIN => $^O eq 'MSWin32';
@@ -383,6 +383,7 @@ use warnings;
     use Doit::Log;
 
     my $diff_error_shown;
+    our @diff_cmd;
 
     sub _new {
 	my $class = shift;
@@ -1534,11 +1535,39 @@ use warnings;
 	    $file2 = '-';
 	}
 
+	if (!@diff_cmd) {
+	    my @diff_candidates = (['diff', '-u']);
+	    if ($^O eq 'MSWin32') {
+		push @diff_candidates, ['fc'];
+	    }
+	    for my $diff_candidate (@diff_candidates) {
+		if (Doit::Util::is_in_path($diff_candidate->[0])) {
+		    @diff_cmd = @$diff_candidate;
+		    last;
+		}
+	    }
+	    return "(diff not available" . (!$diff_error_shown++ ? ", error: none of the candidates (" . join(", ", map { $_->[0] } @diff_candidates) . ") exist" : "") . ")"
+		if !@diff_cmd;
+	}
+
+	my $cannot_use_dash;
+	if ($^O eq 'MSWin32' && $diff_cmd[0] eq 'fc') { # FC cannot handle forward slashes
+	    s{/}{\\}g for ($file1, $file2);
+	    if ($file2 eq '-') {
+		$cannot_use_dash = 1;
+	    }
+	}
+
 	my($diff, $diff_stderr);
-	if (eval { require IPC::Run; 1 }) {
-	    IPC::Run::run(['diff', '-u', $file1, $file2], (defined $stdin ? ('<', \$stdin) : ()), '>', \$diff, '2>', \$diff_stderr);
+	if (!$cannot_use_dash && eval { require IPC::Run; 1 }) {
+	    if (!eval {
+		IPC::Run::run([@diff_cmd, $file1, $file2], (defined $stdin ? ('<', \$stdin) : ()), '>', \$diff, '2>', \$diff_stderr); 1;
+	    }) {
+		$diff = "(diff not available" . (!$diff_error_shown++ ? ", error: $@" : "") . ")";
+		$diff_stderr = '';
+	    }
 	} else {
-	    if ($^O eq 'MSWin32') { # list systems with unreliable IPC::Open3 here
+	    if ($^O eq 'MSWin32' || $cannot_use_dash) { # list systems with unreliable IPC::Open3 here
 		my $tmp;
 		if ($file2 eq '-') {
 		    require File::Temp;
@@ -1548,11 +1577,11 @@ use warnings;
 		    $tmp->close;
 		    $file2 = "$tmp";
 		}
-		my $diffref = _qx('diff', '-u', $file1, $file2);
+		my $diffref = _qx(@diff_cmd, $file1, $file2);
 		$diff = $$diffref;
 		$diff_stderr = '';
 	    } else {
-		($diff, $diff_stderr) = eval { _open3($stdin, 'diff', '-u', $file1, $file2) };
+		($diff, $diff_stderr) = eval { _open3($stdin, @diff_cmd, $file1, $file2) };
 		if ($@) {
 		    $diff = "(diff not available" . (!$diff_error_shown++ ? ", error: $@" : "") . ")";
 		}
